@@ -24,6 +24,7 @@ __all__ = ("ServiceName",)
 
 ServiceName = Literal[
     "accessanalyzer",
+    "account",
     "acm",
     "acm-pca",
     "alexaforbusiness",
@@ -56,6 +57,7 @@ ServiceName = Literal[
     "chime-sdk-identity",
     "chime-sdk-messaging",
     "cloud9",
+    "cloudcontrol",
     "clouddirectory",
     "cloudformation",
     "cloudfront",
@@ -134,6 +136,7 @@ ServiceName = Literal[
     "glacier",
     "globalaccelerator",
     "glue",
+    "grafana",
     "greengrass",
     "greengrassv2",
     "groundstation",
